@@ -14,8 +14,8 @@
 #include <QHostAddress>
 
 // KDE includes
-#include <KI18n/KLocalizedString>
-#include <KIconThemes/KIconLoader>
+#include <KIconLoader>
+#include <KLocalizedString>
 
 using namespace Smb4KGlobal;
 
@@ -35,17 +35,8 @@ public:
 Smb4KBookmark::Smb4KBookmark(Smb4KShare *share, const QString &label)
     : d(new Smb4KBookmarkPrivate)
 {
-    if (!share->isHomesShare()) {
-        d->url = share->url();
-    } else {
-        d->url = share->homeUrl();
-    }
-
-    d->workgroup = share->workgroupName();
-    d->type = share->shareType();
+    setShare(share);
     d->label = label;
-    d->icon = KDE::icon(QStringLiteral("folder-network"));
-    d->ip.setAddress(share->hostIpAddress());
 }
 
 Smb4KBookmark::Smb4KBookmark(const Smb4KBookmark &b)
@@ -65,7 +56,21 @@ Smb4KBookmark::~Smb4KBookmark()
 {
 }
 
-void Smb4KBookmark::setWorkgroupName(const QString &workgroup)
+void Smb4KBookmark::setShare(Smb4KShare *share) const
+{
+    if (!share->isHomesShare()) {
+        d->url = share->url();
+    } else {
+        d->url = share->homeUrl();
+    }
+
+    d->workgroup = share->workgroupName();
+    d->type = share->shareType();
+    d->icon = KDE::icon(QStringLiteral("folder-network"));
+    d->ip.setAddress(share->hostIpAddress());
+}
+
+void Smb4KBookmark::setWorkgroupName(const QString &workgroup) const
 {
     d->workgroup = workgroup;
 }
@@ -75,22 +80,11 @@ QString Smb4KBookmark::workgroupName() const
     return d->workgroup;
 }
 
-void Smb4KBookmark::setHostName(const QString &host)
-{
-    d->url.setHost(host);
-    d->url.setScheme(QStringLiteral("smb"));
-}
-
 QString Smb4KBookmark::hostName() const
 {
     return d->url.host().toUpper();
 }
 
-void Smb4KBookmark::setShareName(const QString &share)
-{
-    d->url.setPath(share);
-}
-
 QString Smb4KBookmark::shareName() const
 {
     if (d->url.path().startsWith(QStringLiteral("/"))) {
@@ -100,7 +94,7 @@ QString Smb4KBookmark::shareName() const
     return d->url.path();
 }
 
-void Smb4KBookmark::setHostIpAddress(const QString &ip)
+void Smb4KBookmark::setHostIpAddress(const QString &ip) const
 {
     d->ip.setAddress(ip);
 }
@@ -110,7 +104,7 @@ QString Smb4KBookmark::hostIpAddress() const
     return d->ip.toString();
 }
 
-void Smb4KBookmark::setShareType(Smb4KGlobal::ShareType type)
+void Smb4KBookmark::setShareType(Smb4KGlobal::ShareType type) const
 {
     d->type = type;
 }
@@ -120,7 +114,7 @@ Smb4KGlobal::ShareType Smb4KBookmark::shareType() const
     return d->type;
 }
 
-void Smb4KBookmark::setLabel(const QString &label)
+void Smb4KBookmark::setLabel(const QString &label) const
 {
     d->label = label;
 }
@@ -130,7 +124,7 @@ QString Smb4KBookmark::label() const
     return d->label;
 }
 
-void Smb4KBookmark::setUserName(const QString &name)
+void Smb4KBookmark::setUserName(const QString &name) const
 {
     d->url.setUserName(name);
 }
@@ -140,7 +134,7 @@ QString Smb4KBookmark::userName() const
     return d->url.userName();
 }
 
-void Smb4KBookmark::setUrl(const QUrl &url)
+void Smb4KBookmark::setUrl(const QUrl &url) const
 {
     d->url = url;
     d->url.setScheme(QStringLiteral("smb"));
@@ -151,7 +145,7 @@ QUrl Smb4KBookmark::url() const
     return d->url;
 }
 
-void Smb4KBookmark::setCategoryName(const QString &name)
+void Smb4KBookmark::setCategoryName(const QString &name) const
 {
     d->category = name;
 }
@@ -161,7 +155,7 @@ QString Smb4KBookmark::categoryName() const
     return d->category;
 }
 
-void Smb4KBookmark::setProfile(const QString &profile)
+void Smb4KBookmark::setProfile(const QString &profile) const
 {
     d->profile = profile;
 }
@@ -171,7 +165,7 @@ QString Smb4KBookmark::profile() const
     return d->profile;
 }
 
-void Smb4KBookmark::setIcon(const QIcon &icon)
+void Smb4KBookmark::setIcon(const QIcon &icon) const
 {
     d->icon = icon;
 }
@@ -185,3 +179,9 @@ QString Smb4KBookmark::displayString() const
 {
     return i18n("%1 on %2", shareName(), hostName());
 }
+
+Smb4KBookmark &Smb4KBookmark::operator=(const Smb4KBookmark &other)
+{
+    *d = *other.d;
+    return *this;
+}
