@@ -1,7 +1,7 @@
 /*
     This class handles the bookmarks.
 
-    SPDX-FileCopyrightText: 2004-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2004-2025 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -15,6 +15,11 @@
 #include "smb4kshare.h"
 
 // Qt includes
+#if (QT_VERSION >= QT_VERSION_CHECK(6,8,0))
+#include <QApplicationStatic>
+#else
+#include <qapplicationstatic.h>
+#endif
 #include <QDir>
 #include <QFile>
 #include <QMutableListIterator>
@@ -39,7 +44,7 @@ public:
     Smb4KBookmarkHandler instance;
 };
 
-Q_GLOBAL_STATIC(Smb4KBookmarkHandlerStatic, p);
+Q_APPLICATION_STATIC(Smb4KBookmarkHandlerStatic, p);
 
 Smb4KBookmarkHandler::Smb4KBookmarkHandler(QObject *parent)
     : QObject(parent)
