@@ -1,7 +1,7 @@
 /*
     Smb4K's container class for information about a directory or file.
 
-    SPDX-FileCopyrightText: 2018-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2018-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -15,7 +15,7 @@
 
 // KDE includes
 #include <KIO/Global>
-#include <KIconThemes/KIconLoader>
+#include <KIconLoader>
 
 using namespace Smb4KGlobal;
 
@@ -24,19 +24,16 @@ class Smb4KFilePrivate
 public:
     QString workgroupName;
     QHostAddress ip;
+    bool isDirectory;
 };
 
-Smb4KFile::Smb4KFile(const QUrl &url, Smb4KGlobal::NetworkItem type)
-    : Smb4KBasicNetworkItem(type)
+Smb4KFile::Smb4KFile(const QUrl &url)
+    : Smb4KBasicNetworkItem(Smb4KGlobal::FileOrDirectory)
     , d(new Smb4KFilePrivate)
 {
     *pUrl = url;
-
-    if (type == Directory) {
-        *pIcon = KDE::icon(QStringLiteral("folder"));
-    } else {
-        *pIcon = KDE::icon(KIO::iconNameForUrl(url));
-    }
+    *pIcon = KDE::icon(KIO::iconNameForUrl(url));
+    d->isDirectory = false;
 }
 
 Smb4KFile::Smb4KFile(const Smb4KFile &file)
@@ -46,11 +43,18 @@ Smb4KFile::Smb4KFile(const Smb4KFile &file)
     *d = *file.d;
 }
 
+Smb4KFile::Smb4KFile()
+    : Smb4KBasicNetworkItem(Smb4KGlobal::FileOrDirectory)
+    , d(new Smb4KFilePrivate)
+{
+    d->isDirectory = false;
+}
+
 Smb4KFile::~Smb4KFile()
 {
 }
 
-void Smb4KFile::setWorkgroupName(const QString &name)
+void Smb4KFile::setWorkgroupName(const QString &name) const
 {
     d->workgroupName = name;
 }
@@ -65,7 +69,7 @@ QString Smb4KFile::hostName() const
     return pUrl->host().toUpper();
 }
 
-void Smb4KFile::setHostIpAddress(const QHostAddress &address)
+void Smb4KFile::setHostIpAddress(const QHostAddress &address) const
 {
     if (!address.isNull() && address.protocol() != QAbstractSocket::UnknownNetworkLayerProtocol) {
         d->ip = address;
@@ -87,7 +91,7 @@ QString Smb4KFile::shareName() const
     return pUrl->path().section(QStringLiteral("/"), 1, 1);
 }
 
-void Smb4KFile::setUserName(const QString &name)
+void Smb4KFile::setUserName(const QString &name) const
 {
     pUrl->setUserName(name);
 }
@@ -97,7 +101,7 @@ QString Smb4KFile::userName() const
     return pUrl->userName();
 }
 
-void Smb4KFile::setPassword(const QString &pass)
+void Smb4KFile::setPassword(const QString &pass) const
 {
     pUrl->setPassword(pass);
 }
@@ -107,27 +111,25 @@ QString Smb4KFile::password() const
     return pUrl->password();
 }
 
+void Smb4KFile::setDirectory(bool directory) const
+{
+    d->isDirectory = directory;
+    *pIcon = KDE::icon(QStringLiteral("folder"));
+}
+
 bool Smb4KFile::isDirectory() const
 {
-    return (type() == Directory);
+    return d->isDirectory;
 }
 
 QString Smb4KFile::name() const
 {
     QString name;
 
-    switch (type()) {
-    case Directory: {
+    if (d->isDirectory) {
         name = pUrl->path().section(QDir::separator(), -1, -1);
-        break;
-    }
-    case File: {
+    } else {
         name = pUrl->fileName();
-        break;
-    }
-    default: {
-        break;
-    }
     }
 
     return name;
@@ -137,3 +139,9 @@ bool Smb4KFile::isHidden() const
 {
     return name().startsWith(QStringLiteral("."));
 }
+
+Smb4KFile &Smb4KFile::operator=(const Smb4KFile &other)
+{
+    *d = *other.d;
+    return *this;
+}
