@@ -15,6 +15,11 @@
 #include "smb4ksynchronizer.h"
 
 // Qt includes
+#if (QT_VERSION >= QT_VERSION_CHECK(6,8,0))
+#include <QApplicationStatic>
+#else
+#include <qapplicationstatic.h>
+#endif
 #include <QDebug>
 #include <QDirIterator>
 #include <QEventLoop>
@@ -27,7 +32,7 @@
 #include <KIO/CommandLauncherJob>
 #include <KIO/OpenUrlJob>
 
-Q_GLOBAL_STATIC(Smb4KGlobalPrivate, p);
+Q_APPLICATION_STATIC(Smb4KGlobalPrivate, p);
 QRecursiveMutex mutex;
 
 const QList<WorkgroupPtr> &Smb4KGlobal::workgroupsList()
