@@ -1,7 +1,7 @@
 /*
     Provides an interface to the computer's hardware
 
-    SPDX-FileCopyrightText: 2015-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2015-2025 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -12,6 +12,11 @@
 #include <unistd.h>
 
 // Qt includes
+#if (QT_VERSION >= QT_VERSION_CHECK(6,8,0))
+#include <QApplicationStatic>
+#else
+#include <qapplicationstatic.h>
+#endif
 #include <QDBusConnection>
 #include <QDBusInterface>
 #include <QDBusReply>
@@ -52,7 +57,7 @@ public:
     Smb4KHardwareInterface instance;
 };
 
-Q_GLOBAL_STATIC(Smb4KHardwareInterfaceStatic, p);
+Q_APPLICATION_STATIC(Smb4KHardwareInterfaceStatic, p);
 
 Smb4KHardwareInterface::Smb4KHardwareInterface(QObject *parent)
     : QObject(parent)
