@@ -1,7 +1,7 @@
 /*
     The core class that mounts the shares.
 
-    SPDX-FileCopyrightText: 2003-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2003-2025 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -28,6 +28,11 @@
 
 // Qt includes
 #include <QApplication>
+#if (QT_VERSION >= QT_VERSION_CHECK(6,8,0))
+#include <QApplicationStatic>
+#else
+#include <qapplicationstatic.h>
+#endif
 #include <QDebug>
 #include <QDir>
 #include <QFileInfo>
@@ -74,7 +79,7 @@ public:
     Smb4KMounter instance;
 };
 
-Q_GLOBAL_STATIC(Smb4KMounterStatic, p);
+Q_APPLICATION_STATIC(Smb4KMounterStatic, p);
 
 Smb4KMounter::Smb4KMounter(QObject *parent)
     : KCompositeJob(parent)
