@@ -1,7 +1,7 @@
 /*
     This class provides notifications for Smb4K.
 
-    SPDX-FileCopyrightText: 2010-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2010-2025 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -14,6 +14,11 @@
 #include "smb4kworkgroup.h"
 
 // Qt includes
+#if (QT_VERSION >= QT_VERSION_CHECK(6,8,0))
+#include <QApplicationStatic>
+#else
+#include <qapplicationstatic.h>
+#endif
 #include <QEventLoop>
 
 // KDE includes
@@ -32,7 +37,7 @@ public:
     QString componentName;
 };
 
-Q_GLOBAL_STATIC(Smb4KNotificationPrivate, p);
+Q_APPLICATION_STATIC(Smb4KNotificationPrivate, p);
 
 void Smb4KNotification::setComponentName(const QString &name)
 {
