@@ -1,7 +1,7 @@
 /*
     This class manages the profiles that were defined by the user.
 
-    SPDX-FileCopyrightText: 2014-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2014-2025 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -11,6 +11,11 @@
 
 // Qt includes
 #include <QApplication>
+#if (QT_VERSION >= QT_VERSION_CHECK(6,8,0))
+#include <QApplicationStatic>
+#else
+#include <qapplicationstatic.h>
+#endif
 #include <QPointer>
 
 class Smb4KProfileManagerPrivate
@@ -27,7 +32,7 @@ public:
     Smb4KProfileManager instance;
 };
 
-Q_GLOBAL_STATIC(Smb4KProfileManagerStatic, p);
+Q_APPLICATION_STATIC(Smb4KProfileManagerStatic, p);
 
 Smb4KProfileManager::Smb4KProfileManager(QObject *parent)
     : QObject(parent)
