@@ -1,7 +1,7 @@
 /*
     This is the new synchronizer of Smb4K.
 
-    SPDX-FileCopyrightText: 2011-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2011-2025 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -13,13 +13,18 @@
 #include "smb4ksynchronizer_p.h"
 
 // Qt includes
+#if (QT_VERSION >= QT_VERSION_CHECK(6,8,0))
+#include <QApplicationStatic>
+#else
+#include <qapplicationstatic.h>
+#endif
 #include <QCoreApplication>
 #include <QDebug>
 #include <QTimer>
 
 using namespace Smb4KGlobal;
 
-Q_GLOBAL_STATIC(Smb4KSynchronizerStatic, p);
+Q_APPLICATION_STATIC(Smb4KSynchronizerStatic, p);
 
 Smb4KSynchronizer::Smb4KSynchronizer(QObject *parent)
     : KCompositeJob(parent)
