@@ -2,7 +2,7 @@
     This class derives from QObject and encapsulates a bookmark item. It
     is for use with QtQuick.
 
-    SPDX-FileCopyrightText: 2013-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2013-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -13,7 +13,7 @@
 #include <QHostAddress>
 
 // KDE includes
-#include <KIconThemes/KIconLoader>
+#include <KIconLoader>
 
 class Smb4KBookmarkObjectPrivate
 {
@@ -26,6 +26,7 @@ public:
     bool isCategory;
     bool isMounted;
     QHostAddress hostIp;
+    QIcon icon;
 };
 
 Smb4KBookmarkObject::Smb4KBookmarkObject(Smb4KBookmark *bookmark, QObject *parent)
@@ -40,6 +41,7 @@ Smb4KBookmarkObject::Smb4KBookmarkObject(Smb4KBookmark *bookmark, QObject *paren
     d->isCategory = false;
     d->isMounted = false;
     d->hostIp.setAddress(bookmark->hostIpAddress());
+    d->icon = bookmark->icon();
 }
 
 Smb4KBookmarkObject::Smb4KBookmarkObject(const QString &categoryName, QObject *parent)
@@ -49,6 +51,7 @@ Smb4KBookmarkObject::Smb4KBookmarkObject(const QString &categoryName, QObject *p
     d->category = categoryName;
     d->isCategory = true;
     d->isMounted = false;
+    d->icon = KDE::icon(QStringLiteral("folder-bookmark"));
 }
 
 Smb4KBookmarkObject::Smb4KBookmarkObject(QObject *parent)
@@ -176,3 +179,8 @@ void Smb4KBookmarkObject::setHostIpAddress(const QString &ip)
         Q_EMIT changed();
     }
 }
+
+QIcon Smb4KBookmarkObject::icon() const
+{
+    return d->icon;
+}
