@@ -73,7 +73,7 @@ Smb4KConfigPageNetwork::Smb4KConfigPageNetwork(QWidget *parent)
 
     QList<KCoreConfigSkeleton::ItemEnum::Choice> minimalProtocolVersionChoices = Smb4KSettings::self()->minimalClientProtocolVersionItem()->choices();
 
-    for (const KCoreConfigSkeleton::ItemEnum::Choice &c : qAsConst(minimalProtocolVersionChoices)) {
+    for (const KCoreConfigSkeleton::ItemEnum::Choice &c : std::as_const(minimalProtocolVersionChoices)) {
         minimalProtocolVersion->addItem(c.label);
     }
 
@@ -88,7 +88,7 @@ Smb4KConfigPageNetwork::Smb4KConfigPageNetwork(QWidget *parent)
 
     QList<KCoreConfigSkeleton::ItemEnum::Choice> maximalProtocolVersionChoices = Smb4KSettings::self()->maximalClientProtocolVersionItem()->choices();
 
-    for (const KCoreConfigSkeleton::ItemEnum::Choice &c : qAsConst(maximalProtocolVersionChoices)) {
+    for (const KCoreConfigSkeleton::ItemEnum::Choice &c : std::as_const(maximalProtocolVersionChoices)) {
         maximalProtocolVersion->addItem(c.label);
     }
 
@@ -158,7 +158,7 @@ Smb4KConfigPageNetwork::Smb4KConfigPageNetwork(QWidget *parent)
 
     QList<KCoreConfigSkeleton::ItemEnum::Choice> encryptionLevelChoices = Smb4KSettings::self()->encryptionLevelItem()->choices();
 
-    for (const KCoreConfigSkeleton::ItemEnum::Choice &c : qAsConst(encryptionLevelChoices)) {
+    for (const KCoreConfigSkeleton::ItemEnum::Choice &c : std::as_const(encryptionLevelChoices)) {
         encryptionLevel->addItem(c.label);
     }
 
