@@ -1,7 +1,7 @@
 /*
     This is the shares view of Smb4K.
 
-    SPDX-FileCopyrightText: 2006-2022 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2006-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -15,6 +15,7 @@
 // Qt includes
 #include <QDrag>
 #include <QMouseEvent>
+#include <QStorageInfo>
 #include <QWheelEvent>
 
 // KDE includes
@@ -131,11 +132,7 @@ void Smb4KSharesView::mousePressEvent(QMouseEvent *e)
     // Get the item that is under the mouse. If there is no
     // item, unselect the current item.
     //
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     QListWidgetItem *item = itemAt(e->position().toPoint());
-#else
-    QListWidgetItem *item = itemAt(e->pos());
-#endif
 
     if (!item && !selectedItems().isEmpty()) {
         clearSelection();
@@ -169,23 +166,27 @@ void Smb4KSharesView::dragEnterEvent(QDragEnterEvent *e)
 
 void Smb4KSharesView::dragMoveEvent(QDragMoveEvent *e)
 {
-    // Let the QAbstractItemView do the highlighting of the item, etc.
     QAbstractItemView::dragMoveEvent(e);
 
-    // Now we do our thing.
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-    Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(itemAt(e->position().toPoint()));
-#else
-    Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(itemAt(e->pos()));
-#endif
+    if (e->proposedAction() == Qt::CopyAction || e->proposedAction() == Qt::MoveAction) {
+        Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(itemAt(e->position().toPoint()));
 
-    if (item && !item->shareItem()->isInaccessible() && (item->flags() & Qt::ItemIsDropEnabled) && (e->proposedAction() & (Qt::CopyAction | Qt::MoveAction))) {
-        QUrl url = QUrl::fromLocalFile(item->shareItem()->path());
+        if (item) {
+            QStorageInfo storageInfo(item->shareItem()->canonicalPath());
 
-        if (e->source() == this && e->mimeData()->urls().first() == url) {
-            e->ignore();
+            if (!storageInfo.isReadOnly() && !item->shareItem()->isInaccessible() && (item->flags() & Qt::ItemIsDropEnabled)) {
+                QUrl url = QUrl::fromLocalFile(item->shareItem()->path());
+
+                if (e->source() == this && e->mimeData()->urls().first() == url) {
+                    e->ignore();
+                } else {
+                    e->accept();
+                }
+            } else {
+                e->ignore();
+            }
         } else {
-            e->accept();
+            e->ignore();
         }
     } else {
         e->ignore();
@@ -194,22 +195,28 @@ void Smb4KSharesView::dragMoveEvent(QDragMoveEvent *e)
 
 void Smb4KSharesView::dropEvent(QDropEvent *e)
 {
-    // Get the item and process the drop event
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
-    Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(itemAt(e->position().toPoint()));
-#else
-    Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(itemAt(e->pos()));
-#endif
+    if (e->proposedAction() == Qt::CopyAction || e->proposedAction() == Qt::MoveAction) {
+        Smb4KSharesViewItem *item = static_cast<Smb4KSharesViewItem *>(itemAt(e->position().toPoint()));
 
-    if (item && !item->shareItem()->isInaccessible() && (e->proposedAction() & (Qt::CopyAction | Qt::MoveAction))) {
-        QUrl url = QUrl::fromLocalFile(item->shareItem()->path());
+        if (item) {
+            QStorageInfo storageInfo(item->shareItem()->canonicalPath());
 
-        if (e->source() == this && e->mimeData()->urls().first() == url) {
-            e->ignore();
+            if (!storageInfo.isReadOnly() && !item->shareItem()->isInaccessible() && (item->flags() & Qt::ItemIsDropEnabled)
+                && (e->proposedAction() == Qt::CopyAction || e->proposedAction() == Qt::MoveAction)) {
+                QUrl url = QUrl::fromLocalFile(item->shareItem()->path());
+
+                if (e->source() == this && e->mimeData()->urls().first() == url) {
+                    e->ignore();
+                } else {
+                    e->acceptProposedAction();
+                    Q_EMIT acceptedDropEvent(item, e);
+                    // e->accept();
+                }
+            } else {
+                e->ignore();
+            }
         } else {
-            e->acceptProposedAction();
-            Q_EMIT acceptedDropEvent(item, e);
-            e->accept();
+            e->ignore();
         }
     } else {
         e->ignore();
@@ -218,15 +225,10 @@ void Smb4KSharesView::dropEvent(QDropEvent *e)
 
 Qt::DropActions Smb4KSharesView::supportedDropActions() const
 {
-    // Only allow copying and linking.
     return (Qt::CopyAction | Qt::LinkAction);
 }
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
 QMimeData *Smb4KSharesView::mimeData(const QList<QListWidgetItem *> &list) const
-#else
-QMimeData *Smb4KSharesView::mimeData(const QList<QListWidgetItem *> list) const
-#endif
 {
     QMimeData *mimeData = new QMimeData();
     QList<QUrl> urls;
