@@ -1,7 +1,7 @@
 /*
     smb4ktooltip  -  Provides tooltips for Smb4K
 
-    SPDX-FileCopyrightText: 2020-2023 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
+    SPDX-FileCopyrightText: 2020-2024 Alexander Reinholdt <alexander.reinholdt@kdemail.net>
     SPDX-License-Identifier: GPL-2.0-or-later
 */
 
@@ -15,6 +15,8 @@
 #include <QHBoxLayout>
 #include <QPoint>
 #include <QWindow>
+#include <QLabel>
+#include <QFormLayout>
 
 // KDE includes
 #include <KToolTipWidget>
@@ -44,7 +46,11 @@ public:
      * @enum NetworkItem  Tooltip reflecting a remote network item
      * @enum MountedShare Tooltip reflecting a mounted share
      */
-    enum Type { NetworkItem, MountedShare, Unknown };
+    enum Type {
+        NetworkItem,
+        MountedShare,
+        Unknown
+    };
 
     /**
      * Set up the tooltip.
@@ -67,7 +73,8 @@ private:
     NetworkItemPtr m_item;
     Type m_type;
     QWidget *m_contentsWidget;
-    QHBoxLayout *m_mainLayout;
+    QLabel *m_iconLabel;
+    QFormLayout *m_formLayout;
 };
 
 #endif
